@@ -173,6 +173,7 @@ class infoRegistry(metaclass=SingletonMeta):
 class VideoDownloader:
     def __init__(self, url, download_directory=None, user_agent=None,
                  video_extention="mp4", download_video=True,
+                 video_path=None,
                  output_filename=None, ydl_opts=None,
                  registry=None, force_refresh=False,
                  flat_layout: bool = False):
@@ -190,7 +191,7 @@ class VideoDownloader:
         self.output_filename = output_filename
         self.force_refresh = force_refresh
         self.flat_layout = flat_layout   # 🔑
-
+        self.video_path=video_path
         self.monitoring = True
         self.pause_event = threading.Event()
 
@@ -252,7 +253,7 @@ class VideoDownloader:
         finally:
             self.stop()
 
-    def _download_single(self, video_url: str):
+    def _download_single(self, video_url: str,video_path:str=None):
         logger.info(f"[VideoDownloader] Processing: {video_url}")
 
         if "youtube.com/watch" in video_url and "v=" not in video_url:
@@ -282,7 +283,7 @@ class VideoDownloader:
                 logger.warning(f"[VideoDownloader] Invalid ext {ext}, forcing mp4")
                 ext = "mp4"
 
-            final_path = os.path.join(dirbase, f"video.{ext}")
+            final_path = video_path or self.video_path or info.get("video_path") or os.path.join(self.download_directory, f"video.{ext}")
             if temp_path != final_path and os.path.isfile(temp_path):
                 shutil.move(temp_path, final_path)
 
@@ -338,6 +339,7 @@ def get_video_info_spec(
     video_url=None,
     download=None
     ):
+
     url = url or video_url
     video_info = get_video_info(
         url=url,
@@ -348,13 +350,17 @@ def get_video_info_spec(
         info_directory=info_directory,
         video_path=video_path,
         download=download
-
     )
+    if not video_info:   # yt-dlp failed
+        logger.warning(f"[get_video_info_spec] No info for {url}")
+        return None
+
     if not key:
         return video_info
+
     value = video_info.get(key)
     if not value:
-         value = make_list(get_any_value(video_info,key) or None)[0]
+        value = make_list(get_any_value(video_info, key) or None)[0]
     return value
 def get_video_id(
     url=None,
